==> pure-maps-2.9.0.tar.gz: pure-maps-2.9.0/docs/index.md <==
# Pure Maps

[![Latest release](https://img.shields.io/github/v/release/rinigus/pure-maps)](https://github.com/rinigus/pure-maps/releases)
[![SFOS](https://img.shields.io/badge/SailfishOS-OpenRepos-1CA198)](https://openrepos.net/content/rinigus/pure-maps)
[![Ubuntu Touch](https://img.shields.io/badge/Ubuntu%20Touch-OpenStore-292929)](https://open-store.io/app/pure-maps.jonnius)
[![Flatpak](https://img.shields.io/badge/Flatpak-Flathub-4A86CF)](https://flathub.org/apps/details/io.github.rinigus.PureMaps)
[![Fedora](https://img.shields.io/badge/O.B.S-Fedora-3C6EB4)](https://build.opensuse.org/package/show/home:rinigus:maps/pure-maps)

[![Matrix](https://img.shields.io/badge/matrix.org-%23pure--maps-blue)](https://matrix.to/#/#pure-maps:matrix.org)
[![TMO](https://img.shields.io/badge/forum-T.M.O-FB9200)](https://talk.maemo.org/showthread.php?t=100442)


Pure Maps is an application for Linux to display vector and raster
maps, places, routes, and provide navigation instructions with a
flexible selection of data and service providers. It is targeting
mobile Linux platforms, such as Sailfish OS, Ubuntu Touch, and others.

This page is a placeholder and users are welcome to contribute the
content. See corresponding
[issue](https://github.com/rinigus/pure-maps/issues/400) for details.


## User feedback

There are three main communication channels with the users: GitHub,
Matrix channel
[#pure-maps:matrix.org](https://matrix.to/#/#pure-maps:matrix.org) and
a thread at [TMO](https://talk.maemo.org/showthread.php?t=100442).

Please use Github issues to address specific problems and development
requests. General discussion is expected either through corresponding
issues, Matrix channel, or TMO thread. Please note that users from all
platforms are welcome at TMO, not only current Sailfish OS users.

==> pure-maps-3.3.0.tar.gz: pure-maps-3.3.0/docs/index.md <==
# Pure Maps

[![Latest release](https://img.shields.io/github/v/release/rinigus/pure-maps)](https://github.com/rinigus/pure-maps/releases)
[![SFOS](https://img.shields.io/badge/SailfishOS-Chum-1CA198)](https://build.sailfishos.org/package/show/sailfishos:chum/pure-maps)
[![Ubuntu Touch](https://img.shields.io/badge/Ubuntu%20Touch-OpenStore-292929)](https://open-store.io/app/pure-maps.jonnius)
[![Flatpak](https://img.shields.io/badge/Flatpak-Flathub-4A86CF)](https://flathub.org/apps/details/io.github.rinigus.PureMaps)
[![Fedora](https://img.shields.io/badge/O.B.S-Fedora-3C6EB4)](https://build.opensuse.org/package/show/home:rinigus:maps/pure-maps)

[![Matrix](https://img.shields.io/badge/matrix.org-%23pure--maps-blue)](https://matrix.to/#/#pure-maps:matrix.org)
[![Discussions](https://img.shields.io/badge/forum-GitHub-FB9200)](https://github.com/rinigus/pure-maps/discussions)


Pure Maps is an application for Linux to display vector and raster
maps, places, routes, and provide navigation instructions with a
flexible selection of data and service providers. It is targeting
mobile Linux platforms, such as Sailfish OS, Ubuntu Touch, and others.

This page is a placeholder and users are welcome to contribute the
content. See corresponding
[issue](https://github.com/rinigus/pure-maps/issues/400) for details.


## User feedback

There are three main communication channels with the users: GitHub
[discussions](https://github.com/rinigus/pure-maps/discussions) and
issues, Matrix channel
[#pure-maps:matrix.org](https://matrix.to/#/#pure-maps:matrix.org) and
a thread at [TMO](https://talk.maemo.org/showthread.php?t=100442).

Please use Github issues to address specific problems and development
requests. General discussion is expected either through corresponding
topics in GitHub discussions, issues, Matrix channel, or TMO
thread.
